==> haskell-http2-1.6.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.1
id: http2-1.6.1-GnS80kD5z2W2Uof1QGQvfC
key: http2-1.6.1-GnS80kD5z2W2Uof1QGQvfC
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: 150cb80ea6433f846327a0aaf9b14528
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/http2-1.6.1
hs-libraries: HShttp2-1.6.1-GnS80kD5z2W2Uof1QGQvfC
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    psqueues-0.2.2.2-Lc5lc6mN2Nu3S7lL5S5EHu
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.2
id: http2-1.6.2-3QsVsbCFFM2DBega6kRGaL
key: http2-1.6.2-3QsVsbCFFM2DBega6kRGaL
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: af2c34c7d39a6ef0f32a8ed22abd1302
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/http2-1.6.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/http2-1.6.2
hs-libraries: HShttp2-1.6.2-3QsVsbCFFM2DBega6kRGaL
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    psqueues-0.2.2.2-Lc5lc6mN2Nu3S7lL5S5EHu
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
